pitchtools.OctaveTranspositionMapping
=====================================

.. abjad-lineage:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping

.. autoclass:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.append
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.count
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.custom_identifier
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.extend
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.index
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.insert
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.item_class
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.keep_sorted
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.pop
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.remove
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.reverse
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.sort
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__call__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__contains__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__delitem__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__eq__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__format__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__getitem__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__iadd__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__iter__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__len__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__makenew__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__ne__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__repr__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__reversed__
      ~abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.custom_identifier
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.keep_sorted
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.append
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.extend
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.index
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.insert
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.pop
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.remove
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.reverse
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__call__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__iadd__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__reversed__
   :noindex:

.. automethod:: abjad.tools.pitchtools.OctaveTranspositionMapping.OctaveTranspositionMapping.__setitem__
   :noindex:
